clear all
set matsize 10000
set maxvar 30000
set mem 4g
set more off



use 		 		 "$output/karna_arra.dta",clear
quietly append using "$output/maha_arra.dta"
quietly append using "$output/madhya_arra.dta"
quietly append using "$output/kerala_arra.dta"
quietly append using "$output/bihar_arra.dta"
quietly append using "$output/up_arra.dta"
quietly append using "$output/raj_arra.dta"
quietly append using "$output/gujarat_arra.dta"
quietly append using "$output/westbengal_arra.dta"
quietly append using "$output/andrah_arra.dta"
quietly append using "$output/tamil_arra.dta"
quietly append using "$output/himachal_arra.dta"
quietly append using "$output/haryana_arra.dta"
quietly append using "$output/punjab_arra.dta"

*generating year of birth
ren hv105 age
ren hv007 itw_yr
ren hv101 rel_head
gen birth = 1900 + itw_yr - age
drop if birth == .

*sex dummie
gen male   = hv104 == 1 if hv104 != .
gen female = hv104 == 2 if hv104 != .
gen bothsex = male + female

*education level dummies
ren hv106 edu_level 
	label var edu_level "Education levels"
	
gen literacy     = sh11 == 1 & sh12 != .
gen primary      = edu_level > 0 & edu_level != .
gen secondary    = edu_level > 1 & edu_level != .
gen higher       = edu_level > 2 & edu_level != .

gen 	education = 0
replace education = 1 if primary
replace education = 2 if secondary
replace education = 3 if higher
	label var education "Education level"

*identifier district
ren hv024 state
egen district = concat(state sdist), punct(" ")

ren sh39 religion
gen hindu = religion == 1
gen sikh = religion == 4
gen buddhist = religion == 5
ren sh41 caste_group

*SC status
gen sc = (sc76 == 1 | sc77 == 1)
	label var sc "SC"

egen casteid = group(caste_clean)


						*-----------------
						*Coding obc status
						*-----------------

gen obc = 0
	label var obc "obc"

*Andrah Pradesh
*--------------
replace obc = 1 if caste_clean == "PALLI" & state == 2
replace obc = 1 if caste_clean == "CHAKALI" & state == 2
replace obc = 1 if caste_clean == "JANGAM" & state == 2
replace obc = 1 if caste_clean == "JOGI" & state == 2
replace obc = 1 if caste_clean == "KORCHA" & state == 2
replace obc = 1 if caste_clean == "KALINGA" & state == 2
replace obc = 1 if caste_clean == "KAIDADI" & state == 2
replace obc = 1 if caste_clean == "VADELU" & state == 2
replace obc = 1 if caste_clean == "DUDEKULA" & state == 2
replace obc = 1 if caste_clean == "GANDLA" & state == 2
replace obc = 1 if caste_clean == "JANDRA" & state == 2
replace obc = 1 if caste_clean == "KULALA" & state == 2
replace obc = 1 if caste_clean == "NEELKANTH" & state == 2
replace obc = 1 if caste_clean == "PERIKA" & state == 2
replace obc = 1 if caste_clean == "KURNI" & state == 2
replace obc = 1 if caste_clean == "PADMASALE" & state == 2
replace obc = 1 if caste_clean == "SRISAINA" & state == 2
replace obc = 1 if caste_clean == "THOGATA" & state == 2
replace obc = 1 if caste_clean == "KATIKA" & state == 2
replace obc = 1 if caste_clean == "HATKAR" & state == 2
replace obc = 1 if caste_clean == "JINGAR" & state == 2
replace obc = 1 if caste_clean == "KANDRA" & state == 2
replace obc = 1 if caste_clean == "KOSTHI" & state == 2
replace obc = 1 if caste_clean == "KACHHI" & state == 2
replace obc = 1 if caste_clean == "KOPPULA VELAMA" & state == 2
replace obc = 1 if caste_clean == "MALI" & state == 2 & caste_group != 2
replace obc = 1 if caste_clean == "MUDIRAJ" & state == 2
replace obc = 1 if caste_clean == "NAGAVASAM" & state == 2
replace obc = 1 if caste_clean == "UPPARA" & state == 2
replace obc = 1 if caste_clean == "VANJARY" & state == 2
replace obc = 1 if caste_clean == "LODHI" & state == 2
replace obc = 1 if caste_clean == "VANNIA" & state == 2
replace obc = 1 if caste_clean == "PATRA" & state == 2
replace obc = 1 if caste_clean == "GUDIYA" & state == 2
replace obc = 1 if caste_clean == "DHANUK" & state == 2
replace obc = 1 if caste_clean == "DHOBI" & state == 2
replace obc = 1 if caste_clean == "DHUNIYA" & state == 2
replace obc = 1 if caste_clean == "DHIMAR" & state == 2
replace obc = 1 if caste_clean == "NAT" & state == 2 & religion == 2
replace obc = 1 if caste_clean == "PRADHAN" & state == 2
replace obc = 1 if caste_clean == "BAGDI" & state == 2
replace obc = 1 if caste_clean == "BARI" & state == 2
replace obc = 1 if caste_clean == "BELDAR" & state == 2
replace obc = 1 if caste_clean == "BARHAI" & state == 2

*Bihar
*-----
replace obc = 1 if caste_clean == "KASAI (M.)" & state == 4
replace obc = 1 if caste_clean == "KEWAT" & state == 4
replace obc = 1 if caste_clean == "KOCH" & state == 4
replace obc = 1 if caste_clean == "KORKU" & state == 4
replace obc = 1 if caste_clean == "KANU" & state == 4
replace obc = 1 if caste_clean == "KAMAR" & state == 4
replace obc = 1 if caste_clean == "KUSHVAHA" & state == 4
replace obc = 1 if caste_clean == "KHATIK" & state == 4
replace obc = 1 if caste_clean == "KHANGAR" & state == 4
replace obc = 1 if caste_clean == "KHATWA" & state == 4
replace obc = 1 if caste_clean == "KHATWE" & state == 4
replace obc = 1 if caste_clean == "KHETAURI" & state == 4
replace obc = 1 if caste_clean == "GADDI (M.)" & state == 4
replace obc = 1 if caste_clean == "GANDHARBA" & state == 4
replace obc = 1 if caste_clean == "GANGAI" & state == 4
replace obc = 1 if caste_clean == "CHIKH" & state == 4
replace obc = 1 if caste_clean == "JOGI" & state == 4
replace obc = 1 if caste_clean == "TANTI" & state == 4
replace obc = 1 if caste_clean == "TELI" & state == 4
replace obc = 1 if caste_clean == "HALWAI" & state == 4
replace obc = 1 if caste_clean == "BHAR" & state == 4
replace obc = 1 if caste_clean == "DARZI" & state == 4
replace obc = 1 if caste_clean == "MALAKAR" & state == 4
replace obc = 1 if caste_clean == "MALLAH" & state == 4
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 4
replace obc = 1 if caste_clean == "BHANGI" & state == 4
replace obc = 1 if caste_clean == "MANGAR" & state == 4
replace obc = 1 if caste_clean == "MARKANDE" & state == 4
replace obc = 1 if caste_clean == "RAJBANSHI" & state == 4
replace obc = 1 if caste_clean == "RANGREZ" & state == 4
replace obc = 1 if caste_clean == "KUNJRA" & state == 4
replace obc = 1 if caste_clean == "LAHERI" & state == 4
replace obc = 1 if caste_clean == "SHIVARI" & state == 4
replace obc = 1 if caste_clean == "SONAR" & state == 4
replace obc = 1 if caste_clean == "DARZI" & state == 4
replace obc = 1 if caste_clean == "DHANWAR" & state == 4
replace obc = 1 if caste_clean == "DANGI" & state == 4
replace obc = 1 if caste_clean == "KALWAR" & state == 4
replace obc = 1 if caste_clean == "KALAL" & state == 4
replace obc = 1 if caste_clean == "KULHAYA" & state == 4
replace obc = 1 if caste_clean == "NAGAR" & state == 4

*Gujarat
*-------
replace obc = 1 if caste_clean == "AGRI" & state == 6
replace obc = 1 if caste_clean == "AHIR" & state == 6
replace obc = 1 if caste_clean == "CHARAN" & state == 6
replace obc = 1 if caste_clean == "GOSWAMY" & state == 6
replace obc = 1 if caste_clean == "DHIMAR" & state == 6
replace obc = 1 if caste_clean == "DABGAR" & state == 6
replace obc = 1 if caste_clean == "DHOBI" & state == 6
replace obc = 1 if caste_clean == "FAKIR" & state == 6
replace obc = 1 if caste_clean == "TELI" & state == 6
replace obc = 1 if caste_clean == "HINGORA" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "JAT" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "KAIKADI" & state == 6
replace obc = 1 if caste_clean == "KASAI (M.)" & state == 6
replace obc = 1 if caste_clean == "KATHIK" & state == 6
replace obc = 1 if caste_clean == "MIRASI" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "KAHAR" & state == 6
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 6
replace obc = 1 if caste_clean == "DARBAR" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "MAKRANI (M.)" & state == 6
replace obc = 1 if caste_clean == "GAVLI" & state == 6
replace obc = 1 if caste_clean == "MER" & state == 6
replace obc = 1 if caste_clean == "NAT" & state == 6
replace obc = 1 if caste_clean == "RABARI" & state == 6
replace obc = 1 if caste_clean == "JINGAR" & state == 6
replace obc = 1 if caste_clean == "SANDHI" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "SARGARA" & state == 6
replace obc = 1 if caste_clean == "NAYAK" & state == 6
replace obc = 1 if caste_clean == "THEBA" & state == 6 & religion == 2
replace obc = 1 if caste_clean == "VADI" & state == 6
replace obc = 1 if caste_clean == "CHAMAR" & state == 6 
replace obc = 1 if caste_clean == "HAJAM" & state == 6
replace obc = 1 if caste_clean == "SATHWARA" & state == 6
replace obc = 1 if caste_clean == "MALI" & state == 6
replace obc = 1 if caste_clean == "BHAR" & state == 6
replace obc = 1 if caste_clean == "LAKHARA" & state == 6
replace obc = 1 if caste_clean == "KOSHTI" & state == 6
replace obc = 1 if caste_clean == "KALAL" & state == 6
replace obc = 1 if caste_clean == "SUTHAR" & state == 6
replace obc = 1 if caste_clean == "LOHAR" & state == 6
replace obc = 1 if caste_clean == "KACHHI" & state == 6
replace obc = 1 if caste_clean == "BHANDARI" & state == 6
replace obc = 1 if caste_clean == "CHHIPPA" & state == 6
replace obc = 1 if caste_clean == "KHAVAS" & state == 6
replace obc = 1 if caste_clean == "SAGAR" & state == 6
replace obc = 1 if caste_clean == "SUMRA" & state == 6

*Haryana
*-------
replace obc = 1 if caste_clean == "TURI" & state == 7
replace obc = 1 if caste_clean == "BAIRAGI" & state == 7
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 7
replace obc = 1 if caste_clean == "BHAT" & state == 7
replace obc = 1 if caste_clean == "LOHAR" & state == 7
replace obc = 1 if caste_clean == "CHANG" & state == 7
replace obc = 1 if caste_clean == "DARZI" & state == 7
replace obc = 1 if caste_clean == "DHOBI" & state == 7
replace obc = 1 if caste_clean == "KAHAR" & state == 7
replace obc = 1 if caste_clean == "FAKIR" & state == 7
replace obc = 1 if caste_clean == "GHIRAT" & state == 7
replace obc = 1 if caste_clean == "GHOSI" & state == 7
replace obc = 1 if caste_clean == "GAWALA" & state == 7
replace obc = 1 if caste_clean == "HAJAM" & state == 7
replace obc = 1 if caste_clean == "SUTHAR" & state == 7
replace obc = 1 if caste_clean == "YOGI" & state == 7
replace obc = 1 if caste_clean == "KANJAR" & state == 7
replace obc = 1 if caste_clean == "KUMHAR" & state == 7
replace obc = 1 if caste_clean == "KUCHBANDIYA" & state == 7
replace obc = 1 if caste_clean == "LOBANA" & state == 7
replace obc = 1 if caste_clean == "MANIHAR" & state == 7
replace obc = 1 if caste_clean == "LOHAR" & state == 7
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 7
replace obc = 1 if caste_clean == "MIRASI" & state == 7
replace obc = 1 if caste_clean == "NAR" & state == 7
replace obc = 1 if caste_clean == "REHAR" & state == 7
replace obc = 1 if caste_clean == "TELI" & state == 7
replace obc = 1 if caste_clean == "BANJARA" & state == 7
replace obc = 1 if caste_clean == "MINA" & state == 7
replace obc = 1 if caste_clean == "CHARAN" & state == 7
replace obc = 1 if caste_clean == "NAT" & state == 7 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "RAIGAR" & state == 7 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "BADI" & state == 7
replace obc = 1 if caste_clean == "LODHI" & state == 7
replace obc = 1 if caste_clean == "MEO" & state == 7
replace obc = 1 if caste_clean == "BHAR" & state == 7
replace obc = 1 if caste_clean == "RANGREZ" & state == 7
replace obc = 1 if caste_clean == "JAISWAR" & state == 7
replace obc = 1 if caste_clean == "GRAMINI" & state == 7

*Himachal Pradesh
*----------------
replace obc = 1 if caste_clean == "TURI" & state == 8
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 8
replace obc = 1 if caste_clean == "BHAT" & state == 8
replace obc = 1 if caste_clean == "LOHAR" & state == 8
replace obc = 1 if caste_clean == "CHANG" & state == 8
replace obc = 1 if caste_clean == "DARZI" & state == 8
replace obc = 1 if caste_clean == "DHOBI" & state == 8
replace obc = 1 if caste_clean == "KAHAR" & state == 8
replace obc = 1 if caste_clean == "FAKIR" & state == 8
replace obc = 1 if caste_clean == "GHIRAT" & state == 8
replace obc = 1 if caste_clean == "GHOSI" & state == 8
replace obc = 1 if caste_clean == "GAWALA" & state == 8
replace obc = 1 if caste_clean == "HAJAM" & state == 8
replace obc = 1 if caste_clean == "SUTHAR" & state == 8
replace obc = 1 if caste_clean == "YOGI" & state == 8
replace obc = 1 if caste_clean == "KANJAR" & state == 8
replace obc = 1 if caste_clean == "KUMHAR" & state == 8
replace obc = 1 if caste_clean == "LOBANA" & state == 8
replace obc = 1 if caste_clean == "MANIHAR" & state == 8
replace obc = 1 if caste_clean == "LOHAR" & state == 8
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 8
replace obc = 1 if caste_clean == "MIRASI" & state == 8
replace obc = 1 if caste_clean == "MALLAH" & state == 8
replace obc = 1 if caste_clean == "MEHRA" & state == 8
replace obc = 1 if caste_clean == "NAR" & state == 8
replace obc = 1 if caste_clean == "NADAF" & state == 8
replace obc = 1 if caste_clean == "GADDI (M.)" & state == 8
replace obc = 1 if caste_clean == "GUJAR" & state == 8
replace obc = 1 if caste_clean == "JULAHA" & state == 8
replace obc = 1 if caste_clean == "BADHAI" & state == 8
replace obc = 1 if caste_clean == "HADI" & state == 8

* Karnataka
*----------
replace obc = 1 if caste_clean == "BAIRAGI" & state == 10
replace obc = 1 if caste_clean == "BOYA" & state == 10
replace obc = 1 if caste_clean == "JOSHI" & state == 10
replace obc = 1 if caste_clean == "GOLLA" & state == 10
replace obc = 1 if caste_clean == "BAGRI" & state == 10
replace obc = 1 if caste_clean == "JOGI" & state == 10
replace obc = 1 if caste_clean == "KAMAN" & state == 10
replace obc = 1 if caste_clean == "KANJAR" & state == 10
replace obc = 1 if caste_clean == "KAIKADI" & state == 10
replace obc = 1 if caste_clean == "NANDIWALE" & state == 10
replace obc = 1 if caste_clean == "PAMLORE" & state == 10
replace obc = 1 if caste_clean == "VADI" & state == 10
replace obc = 1 if caste_clean == "VASUDEV" & state == 10
replace obc = 1 if caste_clean == "VIR" & state == 10
replace obc = 1 if caste_clean == "GAVADA" & state == 10
replace obc = 1 if caste_clean == "DHOBI" & state == 10
replace obc = 1 if caste_clean == "AMBALAKARAN" & state == 10
replace obc = 1 if caste_clean == "BAGDI" & state == 10
replace obc = 1 if caste_clean == "JINGAR" & state == 10
replace obc = 1 if caste_clean == "GHADI" & state == 10
replace obc = 1 if caste_clean == "TELUGUCHETTI" & state == 10
replace obc = 1 if caste_clean == "GUJAR" & state == 10
replace obc = 1 if caste_clean == "GURAV" & state == 10
replace obc = 1 if caste_clean == "KOLI" & state == 10
replace obc = 1 if caste_clean == "KRISHNA GOLLA" & state == 10
replace obc = 1 if caste_clean == "HONNIYAR" & state == 10
replace obc = 1 if caste_clean == "MALI" & state == 10
replace obc = 1 if caste_clean == "KARUVA" & state == 10
replace obc = 1 if caste_clean == "KHATIK" & state == 10
replace obc = 1 if caste_clean == "KASAR" & state == 10
replace obc = 1 if caste_clean == "KOLLA" & state == 10
replace obc = 1 if caste_clean == "KOTEGAR" & state == 10 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "KUDUBI" & state == 10
replace obc = 1 if caste_clean == "KUNBI" & state == 10
replace obc = 1 if caste_clean == "KUSAVAN" & state == 10
replace obc = 1 if caste_clean == "BHARWAD" & state == 10
replace obc = 1 if caste_clean == "MANNAN" & state == 10
replace obc = 1 if caste_clean == "OTARI" & state == 10
replace obc = 1 if caste_clean == "PADIT" & state == 10
replace obc = 1 if caste_clean == "PANSA" & state == 10
replace obc = 1 if caste_clean == "PANDARAM" & state == 10
replace obc = 1 if caste_clean == "PATRA" & state == 10
replace obc = 1 if caste_clean == "RAJAPURI" & state == 10
replace obc = 1 if caste_clean == "SANYASI" & state == 10
replace obc = 1 if caste_clean == "SATARKAR" & state == 10
replace obc = 1 if caste_clean == "SUDIR" & state == 10
replace obc = 1 if caste_clean == "PALLI" & state == 10
replace obc = 1 if caste_clean == "UPPAR" & state == 10
replace obc = 1 if caste_clean == "VETTUVAN" & state == 10
replace obc = 1 if caste_clean == "HINDUMARAVAR" & state == 10
replace obc = 1 if caste_clean == "EZHAVA" & state == 10
replace obc = 1 if caste_clean == "VAKKALIGA" & state == 10
replace obc = 1 if caste_clean == "DARZI" & state == 10
replace obc = 1 if caste_clean == "DEVANGAN" & state == 10
replace obc = 1 if caste_clean == "PADMASALE" & state == 10
replace obc = 1 if caste_clean == "SONAR" & state == 10
replace obc = 1 if caste_clean == "DEVADEGA" & state == 10
replace obc = 1 if caste_clean == "HAJAM" & state == 10
replace obc = 1 if caste_clean == "TELI" & state == 10
replace obc = 1 if caste_clean == "RAJPUT" & state == 10
replace obc = 1 if caste_clean == "VAISHNAVA" & state == 10
replace obc = 1 if caste_clean == "BALIJA" & state == 10
replace obc = 1 if caste_clean == "MANSURI (M.)" & state == 10
replace obc = 1 if caste_clean == "KOMARPAIK" & state == 10
replace obc = 1 if caste_clean == "BAGHBAN (M.)" & state == 10
replace obc = 1 if caste_clean == "ANDIPANDARAM" & state == 10
replace obc = 1 if religion == 2 & state == 10 & caste_clean != "BHORA" & caste_clean != "SHEKH (M.)" & caste_clean != "PATHAN (M.)" & caste_clean != "MUGHAL (M.)"

* Kerala
*-------
replace obc = 1 if caste_clean == "AGASA" & state == 11
replace obc = 1 if caste_clean == "AMBALAKARAN" & state == 11
replace obc = 1 if caste_clean == "ANGLOINDIAN" & state == 11
replace obc = 1 if caste_clean == "BANDARI" & state == 11
replace obc = 1 if caste_clean == "BILLAVA" & state == 11
replace obc = 1 if caste_clean == "DEVADIGU" & state == 11
replace obc = 1 if caste_clean == "DHEEVARA" & state == 11
replace obc = 1 if caste_clean == "EZHAVA" & state == 11
replace obc = 1 if caste_clean == "EZHUTACHAN" & state == 11
replace obc = 1 if caste_clean == "GOWDA" & state == 11
replace obc = 1 if caste_clean == "HEGDE" & state == 11
replace obc = 1 if caste_clean == "JOGI" & state == 11
replace obc = 1 if caste_clean == "KAMSALA" & state == 11
replace obc = 1 if caste_clean == "MUDALI" & state == 11
replace obc = 1 if caste_clean == "KUDUMBI" & state == 11
replace obc = 1 if caste_clean == "KUSAVAN" & state == 11
replace obc = 1 if caste_clean == "MADIVALA" & state == 11
replace obc = 1 if caste_clean == "MAPPILA (M.)" & state == 11
replace obc = 1 if caste_clean == "MARUTHUVAR" & state == 11
replace obc = 1 if caste_clean == "HINDUNADAR" & state == 11
replace obc = 1 if caste_clean == "ODAN" & state == 11
replace obc = 1 if caste_clean == "PANDITHAR" & state == 11
replace obc = 1 if caste_clean == "CHALIYA" & state == 11
replace obc = 1 if caste_clean == "VADUGAN" & state == 11
replace obc = 1 if caste_clean == "VAKKALIGA" & state == 11
replace obc = 1 if caste_clean == "JANGAM" & state == 11
replace obc = 1 if caste_clean == "GOUNDER" & state == 11

*Madhya Pradesh
*--------------
replace obc = 1 if caste_clean == "AHIR" & state == 12
replace obc = 1 if caste_clean == "BAIRAGI" & state == 12
replace obc = 1 if caste_clean == "BANJARA" & state == 12
replace obc = 1 if caste_clean == "BARI" & state == 12
replace obc = 1 if caste_clean == "BARHAI" & state == 12
replace obc = 1 if caste_clean == "VASUDEV" & state == 12
replace obc = 1 if caste_clean == "BHAT" & state == 12
replace obc = 1 if caste_clean == "CHHIPPA" & state == 12
replace obc = 1 if caste_clean == "KAHAR" & state == 12
replace obc = 1 if caste_clean == "POWAR" & state == 12
replace obc = 1 if caste_clean == "BHURTIA" & state == 12
replace obc = 1 if caste_clean == "DARJI" & state == 12
replace obc = 1 if caste_clean == "DHOBI" & state == 12 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "MINA" & state == 12
replace obc = 1 if caste_clean == "DHANGAR" & state == 12
replace obc = 1 if caste_clean == "DHUNIYA" & state == 12
replace obc = 1 if caste_clean == "DHAKAR" & state == 12
replace obc = 1 if caste_clean == "MALA" & state == 12
replace obc = 1 if caste_clean == "GURAV" & state == 12
replace obc = 1 if caste_clean == "GOSWAMY" & state == 12
replace obc = 1 if caste_clean == "LOHAR" & state == 12
replace obc = 1 if caste_clean == "SONAR" & state == 12
replace obc = 1 if caste_clean == "MALI" & state == 12
replace obc = 1 if caste_clean == "KASAR" & state == 12
replace obc = 1 if caste_clean == "KUMHAR" & state == 12
replace obc = 1 if caste_clean == "KUNBI" & state == 12
replace obc = 1 if caste_clean == "KALAR" & state == 12
replace obc = 1 if caste_clean == "KOLTA" & state == 12
replace obc = 1 if caste_clean == "LONIYA" & state == 12
replace obc = 1 if caste_clean == "MHALI" & state == 12
replace obc = 1 if caste_clean == "NAYATA" & state == 12
replace obc = 1 if caste_clean == "PATWA" & state == 12
replace obc = 1 if caste_clean == "LODHI" & state == 12
replace obc = 1 if caste_clean == "TELI" & state == 12
replace obc = 1 if caste_clean == "WADDAR" & state == 12
replace obc = 1 if caste_clean == "ROTIYA" & state == 12
replace obc = 1 if caste_clean == "KOTWAR" & state == 12
replace obc = 1 if caste_clean == "KHAROL" & state == 12
replace obc = 1 if caste_clean == "DANGI" & state == 12
replace obc = 1 if caste_clean == "MER" & state == 12
replace obc = 1 if caste_clean == "HELA" & state == 12
replace obc = 1 if caste_clean == "DHOBI" & state == 12
replace obc = 1 if caste_clean == "MEO" & state == 12
replace obc = 1 if caste_clean == "FAKIR" & state == 12
replace obc = 1 if caste_clean == "MANIHAR" & state == 12
replace obc = 1 if caste_clean == "KASAI (M.)" & state == 12
replace obc = 1 if caste_clean == "MIRASI" & state == 12
replace obc = 1 if caste_clean == "BARHAI" & state == 12
replace obc = 1 if caste_clean == "HAJAM" & state == 12
replace obc = 1 if caste_clean == "MIRDHA" & state == 12
replace obc = 1 if caste_clean == "NAT" & state == 12 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "GADDI (M.)" & state == 12
replace obc = 1 if caste_clean == "MUSLIM GHOSHI" & state == 12
replace obc = 1 if caste_clean == "RAJWAR" & state == 12
replace obc = 1 if caste_clean == "SODI" & state == 12

* Maharashtra
*------------
replace obc = 1 if caste_clean == "BAGDI" & state == 13
replace obc = 1 if caste_clean == "BADIA" & state == 13
replace obc = 1 if caste_clean == "BAJIGAR" & state == 13
replace obc = 1 if caste_clean == "BHAND" & state == 13
replace obc = 1 if caste_clean == "BHAVAIYA" & state == 13
replace obc = 1 if caste_clean == "BHISTI" & state == 13
replace obc = 1 if caste_clean == "BARI" & state == 13
replace obc = 1 if caste_clean == "VASUDEV" & state == 13
replace obc = 1 if caste_clean == "BHUJWA" & state == 13
replace obc = 1 if caste_clean == "CHARAN" & state == 13
replace obc = 1 if caste_clean == "CHARODI" & state == 13
replace obc = 1 if caste_clean == "DABGAR" & state == 13
replace obc = 1 if caste_clean == "DHANGAR" & state == 13
replace obc = 1 if caste_clean == "GADRI" & state == 13
replace obc = 1 if caste_clean == "GURAV" & state == 13
replace obc = 1 if caste_clean == "HATKAR" & state == 13
replace obc = 1 if caste_clean == "JATIYA" & state == 13
replace obc = 1 if caste_clean == "JOGI" & state == 13
replace obc = 1 if caste_clean == "JULAHA" & state == 13
replace obc = 1 if caste_clean == "JANGAM" & state == 13
replace obc = 1 if caste_clean == "JINGAR" & state == 13
replace obc = 1 if caste_clean == "KAPDI" & state == 13
replace obc = 1 if caste_clean == "KADERA" & state == 13
replace obc = 1 if caste_clean == "KOLI" & state == 13
replace obc = 1 if caste_clean == "KOSHTI" & state == 13
replace obc = 1 if caste_clean == "KUMHAR" & state == 13
replace obc = 1 if caste_clean == "KUNBI" & state == 13
replace obc = 1 if caste_clean == "KACHHI" & state == 13
replace obc = 1 if caste_clean == "KASAR" & state == 13
replace obc = 1 if caste_clean == "LOHAR" & state == 13
replace obc = 1 if caste_clean == "MACHHI" & state == 13
replace obc = 1 if caste_clean == "MINA" & state == 13
replace obc = 1 if caste_clean == "HAJAM" & state == 13
replace obc = 1 if caste_clean == "NEELKANTH" & state == 13
replace obc = 1 if caste_clean == "PANCHAL" & state == 13
replace obc = 1 if caste_clean == "PANKA" & state == 13
replace obc = 1 if caste_clean == "DHOBI" & state == 13
replace obc = 1 if caste_clean == "BANDI" & state == 13
replace obc = 1 if caste_clean == "RANGARI" & state == 13
replace obc = 1 if caste_clean == "RANGREZ" & state == 13
replace obc = 1 if caste_clean == "RAUTIA" & state == 13
replace obc = 1 if caste_clean == "SANGAR" & state == 13
replace obc = 1 if caste_clean == "SALEWAR" & state == 13
replace obc = 1 if caste_clean == "SHIMPI" & state == 13
replace obc = 1 if caste_clean == "SONAR" & state == 13
replace obc = 1 if caste_clean == "KASAR" & state == 13
replace obc = 1 if caste_clean == "WADI" & state == 13
replace obc = 1 if caste_clean == "BHADAI" & state == 13
replace obc = 1 if caste_clean == "VANJARY" & state == 13
replace obc = 1 if caste_clean == "SUTHAR" & state == 13
replace obc = 1 if caste_clean == "NADAF" & state == 13
replace obc = 1 if caste_clean == "DEVARI" & state == 13
replace obc = 1 if caste_clean == "MALI" & state == 13
replace obc = 1 if caste_clean == "FAKIR" & state == 13
replace obc = 1 if caste_clean == "AHIR" & state == 13
replace obc = 1 if caste_clean == "BEDAR" & state == 13
replace obc = 1 if caste_clean == "WADDAR" & state == 13
replace obc = 1 if caste_clean == "KAIKADI" & state == 13
replace obc = 1 if caste_clean == "BANJARA" & state == 13
replace obc = 1 if caste_clean == "SHIKARI" & state == 13
replace obc = 1 if caste_clean == "BAIRAGI" & state == 13
replace obc = 1 if caste_clean == "BELDAR" & state == 13
replace obc = 1 if caste_clean == "GOLLA" & state == 13
replace obc = 1 if caste_clean == "GOPAL" & state == 13
replace obc = 1 if caste_clean == "JOSHI" & state == 13
replace obc = 1 if caste_clean == "VIR" & state == 13
replace obc = 1 if caste_clean == "NANDIWALE" & state == 13
replace obc = 1 if caste_clean == "SIKLIKER" & state == 13
replace obc = 1 if caste_clean == "VAIDU" & state == 13
replace obc = 1 if caste_clean == "KAHAR" & state == 13
replace obc = 1 if caste_clean == "OTARI" & state == 13
replace obc = 1 if caste_clean == "POWAR" & state == 13
replace obc = 1 if caste_clean == "KHATIK" & state == 13
replace obc = 1 if caste_clean == "KALAR" & state == 13
replace obc = 1 if caste_clean == "YELLAM" & state == 13
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 13
replace obc = 1 if caste_clean == "DARJI" & state == 13
replace obc = 1 if caste_clean == "MAHAT" & state == 13
replace obc = 1 if caste_clean == "BHANGI" & state == 13 & religion == 2

*Punjab
*-------
replace obc = 1 if caste_clean == "TURI" & state == 19
replace obc = 1 if caste_clean == "KANJAR" & state == 19
replace obc = 1 if caste_clean == "NAR" & state == 19
replace obc = 1 if caste_clean == "REHAR" & state == 19
replace obc = 1 if caste_clean == "GHIRAT" & state == 19
replace obc = 1 if caste_clean == "KAHAR" & state == 19
replace obc = 1 if caste_clean == "GHOSI" & state == 19
replace obc = 1 if caste_clean == "KUMHAR" & state == 19
replace obc = 1 if caste_clean == "SAIN" & state == 19
replace obc = 1 if caste_clean == "DHOBI" & state == 19
replace obc = 1 if caste_clean == "BAIRAGI" & state == 19
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 19
replace obc = 1 if caste_clean == "BHAT" & state == 19
replace obc = 1 if caste_clean == "LOHAR" & state == 19
replace obc = 1 if caste_clean == "CHIMBA" & state == 19
replace obc = 1 if caste_clean == "MALLAH" & state == 19
replace obc = 1 if caste_clean == "FAKIR" & state == 19
replace obc = 1 if caste_clean == "GAWALA" & state == 19
replace obc = 1 if caste_clean == "LOHAR" & state == 19
replace obc = 1 if caste_clean == "HAJAM" & state == 19
replace obc = 1 if caste_clean == "MANIHAR" & state == 19
replace obc = 1 if caste_clean == "VANZARA" & state == 19
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 19
replace obc = 1 if caste_clean == "MIRASI" & state == 19
replace obc = 1 if caste_clean == "TELI" & state == 19
replace obc = 1 if caste_clean == "SWARNKAR" & state == 19
replace obc = 1 if caste_clean == "BHAR" & state == 19
replace obc = 1 if caste_clean == "KACHHI" & state == 19

* Rajasthan
*----------
replace obc = 1 if caste_clean == "AHIR" & state == 20
replace obc = 1 if caste_clean == "BHAT" & state == 20
replace obc = 1 if caste_clean == "BANJARA" & state == 20
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 20
replace obc = 1 if caste_clean == "CHARAN" & state == 20
replace obc = 1 if caste_clean == "CHHIPPA" & state == 20
replace obc = 1 if caste_clean == "DARZI" & state == 20
replace obc = 1 if caste_clean == "KAHAR" & state == 20
replace obc = 1 if caste_clean == "GADDI (M.)" & state == 20
replace obc = 1 if caste_clean == "GHANCHI" & state == 20
replace obc = 1 if caste_clean == "GUJAR" & state == 20
replace obc = 1 if caste_clean == "HELA" & state == 20
replace obc = 1 if caste_clean == "JOGI" & state == 20
replace obc = 1 if caste_clean == "KACHHI" & state == 20
replace obc = 1 if caste_clean == "KALAL" & state == 20
replace obc = 1 if caste_clean == "KHAROL" & state == 20
replace obc = 1 if caste_clean == "KIRAR" & state == 20
replace obc = 1 if caste_clean == "KUMHAR" & state == 20
replace obc = 1 if caste_clean == "MANIHAR" & state == 20
replace obc = 1 if caste_clean == "LODHI" & state == 20
replace obc = 1 if caste_clean == "LOHAR" & state == 20
replace obc = 1 if caste_clean == "KUNJRA" & state == 20
replace obc = 1 if caste_clean == "MER" & state == 20
replace obc = 1 if caste_clean == "MIRASI" & state == 20
replace obc = 1 if caste_clean == "SAIN" & state == 20
replace obc = 1 if caste_clean == "PATWA" & state == 20
replace obc = 1 if caste_clean == "RAIKA" & state == 20
replace obc = 1 if caste_clean == "RAWAT" & state == 20
replace obc = 1 if caste_clean == "SWAMY" & state == 20
replace obc = 1 if caste_clean == "TAMOLI" & state == 20
replace obc = 1 if caste_clean == "TELI" & state == 20
replace obc = 1 if caste_clean == "DHOBI" & state == 20 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "RANGREZ" & state == 20
replace obc = 1 if caste_clean == "JAT" & state == 20
replace obc = 1 if caste_clean == "FAKIR" & state == 20
replace obc = 1 if caste_clean == "KASAI (M.)" & state == 20
replace obc = 1 if caste_clean == "SILAWAT" & state == 20
replace obc = 1 if caste_clean == "KALBI" & state == 20

*Tamil Nadu
*----------
replace obc = 1 if caste_clean == "AMBALAKARAN" & state == 22
replace obc = 1 if caste_clean == "ANDIPANDARAM" & state == 22
replace obc = 1 if caste_clean == "ARAYAN" & state == 22
replace obc = 1 if caste_clean == "BOYAR" & state == 22
replace obc = 1 if caste_clean == "BOYA" & state == 22
replace obc = 1 if caste_clean == "DEVANGAR" & state == 22
replace obc = 1 if caste_clean == "DUDEKULA" & state == 22
replace obc = 1 if caste_clean == "ENADI" & state == 22
replace obc = 1 if caste_clean == "EZHAVA" & state == 22
replace obc = 1 if caste_clean == "VADUGAR" & state == 22
replace obc = 1 if caste_clean == "GOUNDER" & state == 22
replace obc = 1 if caste_clean == "GOWDA" & state == 22
replace obc = 1 if caste_clean == "HEGDE" & state == 22
replace obc = 1 if caste_clean == "ILLATHUPILLAIMAR" & state == 22
replace obc = 1 if caste_clean == "ISAIVELLALAR" & state == 22
replace obc = 1 if caste_clean == "JANGAM" & state == 22
replace obc = 1 if caste_clean == "JOGI" & state == 22
replace obc = 1 if caste_clean == "SENGUNTHAR" & state == 22
replace obc = 1 if caste_clean == "KURUP" & state == 22
replace obc = 1 if caste_clean == "KALINGI" & state == 22
replace obc = 1 if caste_clean == "PIRAMALAIKALLAR" & state == 22
replace obc = 1 if caste_clean == "KAMSALA" & state == 22
replace obc = 1 if caste_clean == "PANIKKAR" & state == 22
replace obc = 1 if caste_clean == "KANNADA" & state == 22
replace obc = 1 if caste_clean == "KAVUTHIYAR" & state == 22
replace obc = 1 if caste_clean == "KHATRI" & state == 22
replace obc = 1 if caste_clean == "KUDUMBI" & state == 22
replace obc = 1 if caste_clean == "KULALA" & state == 22
replace obc = 1 if caste_clean == "LABBAI (M.)" & state == 22
replace obc = 1 if caste_clean == "MEDARA" & state == 22
replace obc = 1 if caste_clean == "MALAYAR" & state == 22
replace obc = 1 if caste_clean == "HINDUMARAVAR" & state == 22
replace obc = 1 if caste_clean == "MANGALA" & state == 22
replace obc = 1 if caste_clean == "MEENAVAR" & state == 22
replace obc = 1 if caste_clean == "MUKKUVAN" & state == 22
replace obc = 1 if caste_clean == "MUTHURAJA" & state == 22
replace obc = 1 if caste_clean == "NADAR" & state == 22
replace obc = 1 if caste_clean == "SALIYAR" & state == 22
replace obc = 1 if caste_clean == "PALLI" & state == 22
replace obc = 1 if caste_clean == "THOGATA" & state == 22
replace obc = 1 if caste_clean == "THOTTIYANAYAKKAR" & state == 22
replace obc = 1 if caste_clean == "UPPARA" & state == 22
replace obc = 1 if caste_clean == "VALAIYAR" & state == 22
replace obc = 1 if caste_clean == "MADIVALA" & state == 22
replace obc = 1 if caste_clean == "VELLANCHETTIAR" & state == 22
replace obc = 1 if caste_clean == "VAKKALIGA" & state == 22
replace obc = 1 if caste_clean == "YADAVA" & state == 22
replace obc = 1 if caste_clean == "YERUKULA" & state == 22
replace obc = 1 if caste_clean == "PULAVAR" & state == 22
replace obc = 1 if caste_clean == "THIYYA" & state == 22

* West Bengal
*------------
replace obc = 1 if caste_clean == "BARUJIBI" & state == 23
replace obc = 1 if caste_clean == "AHIR" & state == 23
replace obc = 1 if caste_clean == "KARMAKAR" & state == 23
replace obc = 1 if caste_clean == "MOIRA" & state == 23
replace obc = 1 if caste_clean == "SATCHASHI" & state == 23
replace obc = 1 if caste_clean == "TELI" & state == 23
replace obc = 1 if caste_clean == "YOGI" & state == 23
replace obc = 1 if caste_clean == "NAGAR" & state == 23
replace obc = 1 if caste_clean == "RAJU" & state == 23
replace obc = 1 if caste_clean == "MALAKAR" & state == 23
replace obc = 1 if caste_clean == "TANTI" & state == 23
replace obc = 1 if caste_clean == "TANTUBAY" & state == 23
replace obc = 1 if caste_clean == "DHANUK" & state == 23
replace obc = 1 if caste_clean == "JOGI" & state == 23
replace obc = 1 if caste_clean == "FAKIR" & state == 23
replace obc = 1 if caste_clean == "BHUJEL" & state == 23
replace obc = 1 if caste_clean == "KAHAR" & state == 23
replace obc = 1 if caste_clean == "BHAR" & state == 23
replace obc = 1 if caste_clean == "KHURESHI" & state == 23
replace obc = 1 if caste_clean == "KALWAR" & state == 23
replace obc = 1 if caste_clean == "DHOBI" & state == 23 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "KUNJRA" & state == 23
replace obc = 1 if caste_clean == "RAI" & state == 23
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 23
replace obc = 1 if caste_clean == "DEWAN" & state == 23
replace obc = 1 if caste_clean == "PATIDAR" & state == 23
replace obc = 1 if caste_clean == "HAJAM" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "MAHALDAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "BELDAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "SARDAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "LASKAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "JAMADAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "MAL" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "MAJHI" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "CHAMAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "HALDAR" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "BISWAS" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "MALI" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "GHOSI" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "DARJI" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "MOLLA" & state == 23 & religion == 2
replace obc = 1 if caste_clean == "BARUJIBI" & state == 23 & religion == 2

*Uttar Pradesh
*--------------
replace obc = 1 if caste_clean == "AHIR" & state == 24
replace obc = 1 if caste_clean == "KACHHI" & state == 24
replace obc = 1 if caste_clean == "KAHAR" & state == 24
replace obc = 1 if caste_clean == "MALLAH" & state == 24
replace obc = 1 if caste_clean == "KUMHAR" & state == 24
replace obc = 1 if caste_clean == "KUNJRA" & state == 24
replace obc = 1 if caste_clean == "GUJAR" & state == 24
replace obc = 1 if caste_clean == "GADDI (M.)" & state == 24
replace obc = 1 if caste_clean == "KHURESHI" & state == 24
replace obc = 1 if caste_clean == "JOGI" & state == 24
replace obc = 1 if caste_clean == "TAMOLI" & state == 24
replace obc = 1 if caste_clean == "TELI" & state == 24
replace obc = 1 if caste_clean == "DARZI" & state == 24
replace obc = 1 if caste_clean == "DHIVAR" & state == 24
replace obc = 1 if caste_clean == "FAKIR" & state == 24
replace obc = 1 if caste_clean == "BANJARA" & state == 24
replace obc = 1 if caste_clean == "BARHAI" & state == 24
replace obc = 1 if caste_clean == "BARI" & state == 24
replace obc = 1 if caste_clean == "BAIRAGI" & state == 24
replace obc = 1 if caste_clean == "BIYAR" & state == 24
replace obc = 1 if caste_clean == "BHAR" & state == 24
replace obc = 1 if caste_clean == "BHARBHUNJA" & state == 24
replace obc = 1 if caste_clean == "MALI" & state == 24
replace obc = 1 if caste_clean == "MANIHAR" & state == 24
replace obc = 1 if caste_clean == "MIRASI" & state == 24
replace obc = 1 if caste_clean == "KAYASTH" & state == 24 & religion == 2
replace obc = 1 if caste_clean == "NADAF" & state == 24
replace obc = 1 if caste_clean == "RANGREZ" & state == 24
replace obc = 1 if caste_clean == "LODHI" & state == 24
replace obc = 1 if caste_clean == "LOHAR" & state == 24
replace obc = 1 if caste_clean == "HALWAI" & state == 24
replace obc = 1 if caste_clean == "HAJAM" & state == 24
replace obc = 1 if caste_clean == "HELA" & state == 24
replace obc = 1 if caste_clean == "DHOBI" & state == 24 & sc76 == 0 & sc77 == 0
replace obc = 1 if caste_clean == "MEO" & state == 24
replace obc = 1 if caste_clean == "KOSHTI" & state == 24
replace obc = 1 if caste_clean == "PATWA" & state == 24
replace obc = 1 if caste_clean == "DARUGAR" & state == 24
replace obc = 1 if caste_clean == "MADARI (M.)" & state == 24
replace obc = 1 if caste_clean == "BHAND" & state == 24
replace obc = 1 if caste_clean == "KOLAR" & state == 24
replace obc = 1 if caste_clean == "DOHAR" & state == 24
replace obc = 1 if caste_clean == "GADA" & state == 24

replace obc = 0 if (sc76 == 1 | sc77 == 1)

gen 	type_caste = 1 if sc76 == 1
replace type_caste = 2 if sc77 == 1
replace type_caste = 3 if obc == 1
replace type_caste = 4 if sc76 == 0 & sc77 == 0 & obc == 0

* Identifying the cases in which a caste is considered SC in a state and ST in an other, and dropping them
*AP: none
*Bihar
drop if caste_clean == "BANJARA" & state == 4
drop if caste_clean == "KHARWAR" & state == 4
*Gujarat
drop if caste_clean == "KOLI" & state == 6 
*Haryana: none
*Himachal Pradesh: none
*Karnataka
drop if caste_clean == "BEDAR" & state == 10
drop if caste_clean == "NAYAK" & state == 10
*Kerala: none
*Madhya Pradesh
drop if caste_clean == "BAIGA" & state == 12
*Maharashtra: none
*Punjab: none
*Rajasthan: none
*Tamil Nadu: none
*West Bengal
drop if caste_clean == "KHARWAR" & state == 23
*Uttar PRadesh: none

ren caste caste_original

*Defining somewhere SC
*---------------------
bys casteid: egen temp0 = max(sc76)
bys casteid: egen temp1 = max(sc77)
gen sc_somewhere = (temp0 == 1 | temp1 == 1)
replace sc_somewhere = 0 if (sc76 == 1 | sc77  == 1 | obc == 1)
drop temp*

*dummies for treatment
*---------------------
foreach t in 38 65 71 {
	gen d`t' = (birth >= 19`t') 
}

*weight
*-------
gen weight = hv005 / 10000

* 5 years cohorts
*----------------
gen cohort5 = birth
forvalues X = 1901(5)1995 {
	gen plusfive = `X' + 5
	replace cohort5 = `X' if (birth >= `X' | birth > plusfive)
	drop plusfive
}
replace cohort5 = 1976 if cohort5 == 1981

* 3 years cohorts
*----------------
gen cohort3 = birth
forvalues X = 1899(3)1980 {
	gen plusthree = `X' + 3
	replace cohort3 = `X' if (birth >= `X' | birth > plusthree)
	drop plusthree
}

*measure of  policy at the state level
*-------------------------------------

preserve // spending at age 12
	use "$output/rohini2003.dta", clear
	gen 	state2 = .
	replace state2 = 2 if state == 1
	replace state2 = 4 if state == 3
	replace state2 = 6 if state == 4
	replace state2 = 7 if state == 5
	replace state2 = 10 if state == 8
	replace state2 = 11 if state == 9
	replace state2 = 12 if state == 10
	replace state2 = 13 if state == 11
	replace state2 = 19 if state == 15
	replace state2 = 20 if state == 16
	replace state2 = 22 if state == 18
	replace state2 = 24 if state == 20
	replace state2 = 23 if state == 21
	drop state
	ren state2 state
	drop if state == .
	label def state_name 2 "Andrah Pradesh"
	label def state_name 4 "Bihar", add
	label def state_name 6 "Gujarat", add
	label def state_name 7 "Haryana", add
	label def state_name 8 "Himachal Pradesh", add
	label def state_name 10 "Karnataka", add
	label def state_name 11 "Kerala", add
	label def state_name 12 "Madhya Pradesh", add
	label def state_name 13 "Maharashtra", add
	label def state_name 19 "Punjab", add
	label def state_name 20 "Rajasthan", add
	label def state_name 22 "Tamil Nadu", add
	label def state_name 23 "West Bengal", add
	label def state_name 24 "Uttar Pradesh", add
	label values state state_name
	save "$output/rohini_prepped.dta",replace

	gen birth = year - 12
	keep if birth > 1949
	keep if birth < 1982

	gen temp0 = scexpsh
	egen temp1 = median(temp0)
	gen sc_exp2 = temp0 > temp1
	replace sc_exp2  = . if temp0 == .
	drop temp*

	gen temp0 = edush2
	egen temp1 = median(temp0)
	gen edu_exp2 = temp0 > temp1
	replace edu_exp2  = . if temp0 == .
	drop temp*

	gen temp0 = job
	egen temp1 = median(temp0)
	drop job
	gen job2 = temp0 > temp1
	replace job2  = . if temp0 == .
	drop temp*

	keep state birth sc_exp2 edu_exp2 job2
	drop if sc_exp2==. & edu_exp2==. & job2==. 
	duplicates drop
	save "$dump/temp2.dta", replace
restore

merge m:1 state birth using "$dump/temp2.dta", nogen


*Interaction terms
*-----------------
foreach var of varlist edu_exp* sc_exp* job* {
	gen sc`var'= `var' * sc
	gen sc77`var' =  `var' * sc77
}
gen scmale = sc * male
gen sc77male = sc77 * male
foreach t in 38 65 71 {
	 gen sc77d`t'= sc77 * d`t'
	 gen sc77d`t'male = sc77d`t' * male
	 gen scd`t' = sc * d`t'
	 gen scd`t'male = scd`t' * male
	 foreach u of varlist   edu_exp* sc_exp* job*  {
		 gen sc77d`t'`u' = sc77d`t' * `u'
		 gen scd`t'`u' = scd`t' * `u'
		 gen d`t'`u'		= d`t' * `u'
	 }
}

*sample selection
*----------------
keep if sc76 | sc77 | obc | sc_somewhere
keep if age > 17 & age <= 65
keep if religion == 1 | religion == 4 | religion == 5

*Dummies
*-------
foreach w in rega regb regc regd rege regf regg regh regi regj regk regl regm regn {
	replace `w' = 0 if `w' == .
	egen festate`w' = group(state `w')
}

egen cohortdum = group(cohort5)
egen cohort3dum = group(cohort3)

egen regiondum = group(state reg)
egen regiongenderdum = group(state male)
egen castedum = group(casteid)
egen castegenderdum = group(casteid male)
egen distdum = group(district)
egen birthdum = group(birth)
egen religiondum = group(religion)


quietly xi i.sc77*i.cohort3 i.sc*i.cohort3 


*Labels
*------
label var sc77 "Late SC"
label var sc "SC"
label var sc77d65 "Late SC * post 1965"
label var sc77d38 "Late SC * post 1938"
label var sc77d71 "Late SC * post 1971" 
label var scd65 "SC * post 1965"
label var scd38 "SC * post 1938" 
label var scd71 "SC * post 1971" 
label var d65 "post 1965"
label var d38 "post 1938"
label var d71 "post 1971"

forvalues w = 1935(3)1980 {
	local z = `w' + 2
	label var _IscXcoh_1_`w' "`w'-`z'" 
	label var _Isc7Xcoh_1_`w' "`w'-`z'" 
	label var _Icohort3_`w' "`w'-`z'" 
}

quietly compress

	  
saveold "$output/merge_arra.dta",replace
